@@ -22,6 +22,7 @@ Ext.define('SoL.module.Championships.Actions', {
         EDIT_CHAMPIONSHIP_ACTION: 'edit_championship',
         DOWNLOAD_TOURNEYS_ACTION: 'download_tourneys',
         SHOW_TOURNEYS_ACTION: 'show_tourneys',
+        SHOW_CLUB_ACTION: 'show_club',
         SHOW_RANKING_ACTION: 'show_ranking'
     },
 
@@ -67,6 +68,23 @@ Ext.define('SoL.module.Championships.Actions', {
             }
         }));
 
+        me.showClubAction = me.addAction(new Ext.Action({
+            itemId: ids.SHOW_CLUB_ACTION,
+            text: _('Club'),
+            tooltip: _('Show the club this championship belongs.'),
+            iconCls: 'clubs-icon',
+            disabled: true,
+            needsOneSelectedRow: true,
+            needsCleanStore: true,
+            handler: function() {
+                var record = me.component.getSelectionModel().getSelection()[0];
+                var idclub = record.get('idclub');
+                var module = me.module.app.getModule('clubs-win');
+
+                module.createOrShowWindow(idclub);
+            }
+        }));
+
         me.downloadTourneysAction = me.addAction(new Ext.Action({
             itemId: ids.DOWNLOAD_TOURNEYS_ACTION,
             text: _('Download'),
@@ -110,6 +128,7 @@ Ext.define('SoL.module.Championships.Actions', {
         tbar.add(2, ' ',
                  me.editChampionshipAction,
                  me.showTourneysAction,
+                 me.showClubAction,
                  me.downloadTourneysAction,
                  me.showChampionshipRanking);
 
@@ -295,8 +314,12 @@ Ext.define('SoL.module.Championships', {
 
     id: 'championships-win',
     iconCls: 'championships-icon',
-    launcherText: _('Championships'),
-    launcherTooltip: _('<b>Championships</b><br />Basic championships management'),
+    launcherText: function() {
+        return _('Championships');
+    },
+    launcherTooltip: function() {
+        return _('<b>Championships</b><br />Basic championships management.');
+    },
 
     config: {
         xtype: 'editable-grid',
@@ -333,13 +356,14 @@ Ext.define('SoL.module.Championships', {
                     ]
                 });
                 callback(cfg);
+                me.app.on('logout', function() { delete cfg.metadata; }, me, { single: true });
             });
         } else {
             callback(cfg);
         }
     },
 
-    createOrShowWindow: function(idclub, club, prizes, couplings) {
+    createOrShowWindow: function(idclub, club, prizes, couplings, idchampionship) {
         var me = this;
         var config = me.config;
         var desktop = me.app.getDesktop();
@@ -375,17 +399,24 @@ Ext.define('SoL.module.Championships', {
                     config.newRecordData.idclub = idclub;
                     config.newRecordData.Club = club;
                     config.stickyFilters = [{
-                            property: 'idclub',
-                            value: idclub
+                        property: 'idclub',
+                        value: idclub
                     }];
                 } else {
                     filteredOn = '';
                 }
 
+                if(idchampionship) {
+                    config.filters = [{
+                        property: 'idchampionship',
+                        value: idchampionship
+                    }];
+                }
+
                 win = desktop.createWindow({
                     id: me.id,
-                    title: (me.windowTitle || me.launcherText) + filteredOn,
-                    taskbuttonTooltip: me.launcherTooltip,
+                    title: (me.windowTitle || me.getLauncherText()) + filteredOn,
+                    taskbuttonTooltip: me.getLauncherTooltip(),
                     iconCls: me.iconCls,
                     items: [config],
                     x: size.x,
@@ -465,7 +496,11 @@ Ext.define('SoL.module.MyChampionships', {
     init: function() {
         var me = this;
         var user = me.app.user;
-        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        if(!me.config.orig_dataURL) me.config.orig_dataURL = me.config.dataURL;
+        me.config.dataURL = Ext.String.urlAppend(me.config.orig_dataURL,
+                                                 'filter_idowner=' + (user.is_admin
+                                                                      ? 'NULL'
+                                                                      : user.user_id));
         me.windowTitle = Ext.String.format(_('Championships managed by {0}'), user.fullname);
         me.callParent();
     }
