@@ -406,8 +406,12 @@ Ext.define('SoL.module.Clubs', {
 
     id: 'clubs-win',
     iconCls: 'clubs-icon',
-    launcherText: _('Clubs'),
-    launcherTooltip: _('<b>Clubs</b><br />Basic clubs management'),
+    launcherText: function() {
+        return _('Clubs');
+    },
+    launcherTooltip: function() {
+        return _('<b>Clubs</b><br />Basic clubs management.');
+    },
 
     config: {
         xtype: 'editable-grid',
@@ -457,14 +461,16 @@ Ext.define('SoL.module.Clubs', {
                     ]
                 });
                 callback(cfg);
+                me.app.on('logout', function() { delete cfg.metadata; }, me, { single: true });
             });
         } else {
             callback(cfg);
         }
     },
 
-    createOrShowWindow: function() {
+    createOrShowWindow: function(idclub) {
         var me = this;
+        var config = me.config;
         var desktop = me.app.getDesktop();
         var win = desktop.getWindow(me.id);
 
@@ -479,12 +485,21 @@ Ext.define('SoL.module.Clubs', {
             function(done) {
                 var size = desktop.getReasonableWindowSize(650, 447, "NW");
 
+                if(idclub) {
+                    config = Ext.apply({
+                        filters: [{
+                            property: 'idclub',
+                            value: idclub
+                        }]
+                    }, config);
+                }
+
                 win = desktop.createWindow({
                     id: me.id,
-                    title: me.windowTitle || me.launcherText,
-                    taskbuttonTooltip: me.launcherTooltip,
+                    title: me.windowTitle || me.getLauncherText(),
+                    taskbuttonTooltip: me.getLauncherTooltip(),
                     iconCls: me.iconCls,
-                    items: [me.config],
+                    items: [config],
                     x: size.x,
                     y: size.y,
                     width: size.width,
@@ -562,7 +577,11 @@ Ext.define('SoL.module.MyClubs', {
     init: function() {
         var me = this;
         var user = me.app.user;
-        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        if(!me.config.orig_dataURL) me.config.orig_dataURL = me.config.dataURL;
+        me.config.dataURL = Ext.String.urlAppend(me.config.orig_dataURL,
+                                                 'filter_idowner=' + (user.is_admin
+                                                                      ? 'NULL'
+                                                                      : user.user_id));
         me.windowTitle = Ext.String.format(_('Clubs managed by {0}'), user.fullname);
         me.callParent();
     }
