@@ -400,7 +400,7 @@ Ext.define('SoL.module.Tourneys', {
         return _('Tourneys');
     },
     launcherTooltip: function() {
-        return _('<b>Tourneys</b><br />Basic tourneys management');
+        return _('<b>Tourneys</b><br />Basic tourneys management.');
     },
 
     config: {
